.. pywws - Python software for USB Wireless Weather Stations
   http://github.com/jim-easterbrook/pywws
   Copyright (C) 2008-18  pywws contributors

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

.. image:: img_1504.jpg
   :align: right

.. include:: ../../README.rst
   :end-before: I have written

Documentation is available in the following languages (the non-English versions are not complete or up to date):
   * `English <http://pywws.readthedocs.io/en/>`_
   * `Français <http://pywws.readthedocs.io/fr/>`_ -- translated by Jacques Desroches
   * `Italiano <http://pywws.readthedocs.io/it/>`_ -- translated by Edoardo

.. include:: ../../README.rst
   :start-after: http://pywws.readthedocs.io/
   :end-before: Credits

Documentation for the legacy version is also available on Read the Docs: http://pywws.readthedocs.io/en/legacy/

Installing and upgrading pywws
==============================

pywws can be installed directly from the `Python Package Index`_ (PyPI) using the pip_ command.
See :doc:`guides/getstarted` for full instructions.

Documentation
=============

Documentation is included with pywws downloads, and is also available `online <http://pywws.readthedocs.io/>`_. A good starting place is :doc:`guides/getstarted` which describes in more detail how to install pywws.

If you have questions not answered in the documentation, please join the `pywws Google mailing list / discussion group <http://groups.google.com/group/pywws>`_ and ask there. Note that your first message to the group will not appear immediately -- new posters have to be approved by a moderator, to prevent spam messages.

Contents
--------

.. toctree::
   :maxdepth: 2

   Dependencies <essentials/dependencies>
   User guides <guides/index>
   Python modules <api_index>
   Licence <essentials/LICENCE>
   pywws Contributors <copyright>
   Change log <essentials/CHANGELOG>

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: ../../README.rst
   :start-after: placeholder-credits
